import { Ref } from 'vue';
import { Service } from '@fly-vue/lcdp-designer';
interface IParams {
    service: Ref<Service | undefined>;
    mode: Ref<'design' | 'code' | 'preview'>;
    appId: string | undefined;
    refCodeEditor: Ref<any>;
    title: Ref<string | undefined>;
}
declare type IJson = Record<string, any>;
/**
 * 确保 content 一直是最新的
 * 切换到设计tab时，把 content 赋给 designerContent
 * 切换到代码tab时，把 content 赋给 codeContent
 * 切换到预览tab时，把 content 赋给 previewContent
 * 设计 onChange 时，更新 content 并设置 hasChange 为 true
 * 代码 onChange 时，更新 content 并设置 hasChange 为 true
 * 保存时，使用 content 保存
 *
 * 注意：切换 tab 会触发我们不想要的 onChange 事件，使用 ignoreNextChange 进行规避
 * @param props
 */
export declare function useDesignerContent(props: any, emit: any, params: IParams): {
    content: Ref<IJson | undefined>;
    contentInit: Ref<boolean>;
    designerContent: Ref<IJson | undefined>;
    codeContent: Ref<string | undefined>;
    previewContent: Ref<IJson | undefined>;
    hasChange: Ref<boolean>;
    showedPreview: Ref<boolean>;
    reload: () => Promise<void>;
    refresh: () => Promise<void>;
    save: (disableNotice?: boolean | undefined) => Promise<void>;
    onDesignerChange: () => boolean;
    onCodeChange: () => boolean;
};
export {};
